@@ -6,6 +6,8 @@ use std::fmt;
 use std::process;
 use std::str;
 
+#[cfg(feature = "color")]
+use anstream::panic;
 use predicates::str::PredicateStrExt;
 use predicates_tree::CaseTreeExt;
 
@@ -45,6 +47,7 @@ pub trait OutputAssertExt {
     /// ```
     ///
     /// [`Output`]: std::process::Output
+    #[must_use]
     fn assert(self) -> Assert;
 }
 
@@ -54,15 +57,15 @@ impl OutputAssertExt for process::Output {
     }
 }
 
-impl<'c> OutputAssertExt for &'c mut process::Command {
+impl OutputAssertExt for &mut process::Command {
     fn assert(self) -> Assert {
         let output = match self.output() {
             Ok(output) => output,
             Err(err) => {
-                panic!("Failed to spawn {:?}: {}", self, err);
+                panic!("Failed to spawn {self:?}: {err}");
             }
         };
-        Assert::new(output).append_context("command", format!("{:?}", self))
+        Assert::new(output).append_context("command", format!("{self:?}"))
     }
 }
 
@@ -93,6 +96,7 @@ impl Assert {
     /// Create an `Assert` for a given [`Output`].
     ///
     /// [`Output`]: std::process::Output
+    #[must_use]
     pub fn new(output: process::Output) -> Self {
         Self {
             output,
@@ -122,6 +126,7 @@ impl Assert {
     ///     .append_context("main", "no args")
     ///     .success();
     /// ```
+    #[must_use]
     pub fn append_context<D>(mut self, name: &'static str, context: D) -> Self
     where
         D: fmt::Display + Send + Sync + 'static,
@@ -482,14 +487,9 @@ impl Assert {
 
 impl fmt::Display for Assert {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        let palette = crate::Palette::current();
-        for &(ref name, ref context) in &self.context {
-            writeln!(
-                f,
-                "{}=`{}`",
-                palette.key.paint(name),
-                palette.value.paint(context)
-            )?;
+        let palette = crate::Palette::color();
+        for (name, context) in &self.context {
+            writeln!(f, "{:#}=`{:#}`", palette.key(name), palette.value(context))?;
         }
         output_fmt(&self.output, f)
     }
@@ -550,7 +550,7 @@ where
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoCodePredicate`] for code.
+/// [`predicates_core::Predicate`] used by [`IntoCodePredicate`] for code.
 ///
 /// # Example
 ///
@@ -619,7 +619,7 @@ impl IntoCodePredicate<EqCodePredicate> for i32 {
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoCodePredicate`] for iterables of codes.
+/// [`predicates_core::Predicate`] used by [`IntoCodePredicate`] for iterables of codes.
 ///
 /// # Example
 ///
@@ -744,7 +744,7 @@ where
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoOutputPredicate`] for bytes.
+/// [`predicates_core::Predicate`] used by [`IntoOutputPredicate`] for bytes.
 ///
 /// # Example
 ///
@@ -784,7 +784,7 @@ impl predicates_core::Predicate<[u8]> for BytesContentOutputPredicate {
         &self,
         expected: bool,
         variable: &[u8],
-    ) -> Option<predicates_core::reflection::Case> {
+    ) -> Option<predicates_core::reflection::Case<'_>> {
         let actual = self.eval(variable);
         if expected == actual {
             Some(predicates_core::reflection::Case::new(Some(self), actual))
@@ -817,7 +817,7 @@ impl IntoOutputPredicate<BytesContentOutputPredicate> for &'static [u8] {
 }
 
 /// Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoOutputPredicate`] for [`str`].
+/// [`predicates_core::Predicate`] used by [`IntoOutputPredicate`] for [`str`].
 ///
 /// # Example
 ///
@@ -904,7 +904,7 @@ impl IntoOutputPredicate<StrContentOutputPredicate> for &'static str {
 }
 
 // Keep `predicates` concrete Predicates out of our public API.
-/// [predicates_core::Predicate] used by [`IntoOutputPredicate`] for
+/// [`predicates_core::Predicate`] used by [`IntoOutputPredicate`] for
 /// [`Predicate<str>`][predicates_core::Predicate].
 ///
 /// # Example
@@ -1071,9 +1071,10 @@ impl fmt::Display for AssertError {
         match &self.reason {
             AssertReason::UnexpectedFailure { actual_code } => writeln!(
                 f,
-                "Unexpected failure.\ncode-{}\nstderr=```{}```",
-                actual_code.map_or("<interrupted>".to_owned(), |actual_code| actual_code
-                    .to_string()),
+                "Unexpected failure.\ncode={}\nstderr=```{}```",
+                actual_code
+                    .map(|actual_code| actual_code.to_string())
+                    .unwrap_or_else(|| "<interrupted>".to_owned()),
                 DebugBytes::new(&self.assert.output.stderr),
             ),
             AssertReason::UnexpectedSuccess => {
@@ -1086,13 +1087,13 @@ impl fmt::Display for AssertError {
                 writeln!(f, "Command interrupted")
             }
             AssertReason::UnexpectedReturnCode { case_tree } => {
-                writeln!(f, "Unexpected return code, failed {}", case_tree)
+                writeln!(f, "Unexpected return code, failed {case_tree}")
             }
             AssertReason::UnexpectedStdout { case_tree } => {
-                writeln!(f, "Unexpected stdout, failed {}", case_tree)
+                writeln!(f, "Unexpected stdout, failed {case_tree}")
             }
             AssertReason::UnexpectedStderr { case_tree } => {
-                writeln!(f, "Unexpected stderr, failed {}", case_tree)
+                writeln!(f, "Unexpected stderr, failed {case_tree}")
             }
         }?;
         write!(f, "{}", self.assert)
@@ -1125,7 +1126,7 @@ mod test {
     fn convert_code<I, P>(pred: I) -> P
     where
         I: IntoCodePredicate<P>,
-        P: predicates_core::Predicate<i32>,
+        P: Predicate<i32>,
     {
         pred.into_code()
     }
@@ -1159,7 +1160,7 @@ mod test {
     fn convert_output<I, P>(pred: I) -> P
     where
         I: IntoOutputPredicate<P>,
-        P: predicates_core::Predicate<[u8]>,
+        P: Predicate<[u8]>,
     {
         pred.into_output()
     }
